"""additons to paralel computation

additional and slitly imporved thread"""
from jpe_types.paralel.thread import Thread, LockableThread, threadInharitanceFilter, LogThread

#__all__ = ["Thread", "LockableThread", "threadInharitanceFilter"]